@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request class
 package PONAPI::Client::Request;
 
 use Moose::Role;
@@ -61,11 +61,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request - request class
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
