@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - delete
 package PONAPI::Client::Request::Delete;
 
 use Moose;
@@ -24,11 +24,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Delete - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Delete - request - delete
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
