@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - retrieve
 package PONAPI::Client::Request::Retrieve;
 
 use Moose;
@@ -28,11 +28,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Retrieve - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Retrieve - request - retrieve
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
