@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - retrieve by relationship
 package PONAPI::Client::Request::RetrieveByRelationship;
 
 use Moose;
@@ -29,11 +29,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::RetrieveByRelationship - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::RetrieveByRelationship - request - retrieve by relationship
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
