@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - retrieve relationships
 package PONAPI::Client::Request::RetrieveRelationships;
 
 use Moose;
@@ -27,11 +27,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::RetrieveRelationships - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::RetrieveRelationships - request - retrieve relationships
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
