@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - role - has data
 package PONAPI::Client::Request::Role::HasData;
 
 use Moose::Role;
@@ -39,11 +39,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Role::HasData - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Role::HasData - request - role - has data
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
