@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - role - has filter
 package PONAPI::Client::Request::Role::HasFilter;
 
 use Moose::Role;
@@ -19,11 +19,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Role::HasFilter - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Role::HasFilter - request - role - has filter
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
