@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - role - has one-to-many data
 package PONAPI::Client::Request::Role::HasOneToManyData;
 
 use Moose::Role;
@@ -19,11 +19,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Role::HasOneToManyData - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Role::HasOneToManyData - request - role - has one-to-many data
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
