@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - role - has relationship-update-data
 package PONAPI::Client::Request::Role::HasRelationshipUpdateData;
 
 use Moose::Role;
@@ -20,11 +20,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Role::HasRelationshipUpdateData - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Role::HasRelationshipUpdateData - request - role - has relationship-update-data
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 DESCRIPTION
 
