@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - role - is GET
 package PONAPI::Client::Request::Role::IsGET;
 
 use Moose::Role;
@@ -15,11 +15,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Role::IsGET - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Role::IsGET - request - role - is GET
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
