@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - role - is POST
 package PONAPI::Client::Request::Role::IsPOST;
 
 use Moose::Role;
@@ -15,11 +15,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Role::IsPOST - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Role::IsPOST - request - role - is POST
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
