@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - update
 package PONAPI::Client::Request::Update;
 
 use Moose;
@@ -25,11 +25,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::Update - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::Update - request - update
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
