@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: request - update relationships
 package PONAPI::Client::Request::UpdateRelationships;
 
 use Moose;
@@ -26,11 +26,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Client::Request::UpdateRelationships - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Client::Request::UpdateRelationships - request - update relationships
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
