@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: URI utils
 package PONAPI::Utils::URI;
 
 use strict;
@@ -53,11 +53,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::Utils::URI - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Utils::URI - URI utils
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 AUTHORS
 
